@@ -314,11 +314,17 @@ class Extractor:
         number = None
         another_number = None
         query = text
-        org = utils.max_backward_match(text, self.organization, 40)
-        if len(org) > 0:
-            org = org[0]
-            org_name = org[0]
-            query = query[org[2]:]
+        p = re.compile(u'[\u4e00-\u9fa5]+')
+        res = re.findall(p, query)
+        for part in res:
+            if part in self.organization:
+                org_name = part
+        # org = utils.max_backward_match(text, self.organization, 40)
+        # if len(org) > 0:
+        #     org = org[0]
+        #     org_name = org[0]
+        #     query = query[org[2]:]
+
         res = re.search('[〔\[\(［]?\s*([0-9]{4})\s*[〕\]\)］]?\s*[年]?\s*[第]?([0-9]+)\s*号', query)
         if res:
             year = res.group(1)
@@ -390,7 +396,7 @@ class Extractor:
 
 if __name__ == '__main__':
     et = Extractor()
-    res1, res2, res3, res4 = et.extract_reference_no("")
+    res1, res2, res3, res4 = et.extract_reference_no("银发〔2020〕10号/JR/T 0173-2020")
     print(res1, res2, res3, res4)
     print(datetime.today())
     start = time.time()
