@@ -157,4 +157,11 @@ def _read_table(filename=_get_module_path("unit_transform")):
                 continue
             else:
                 di[line[0]] = [line[1], float(line[2])]
-    return di
\ No newline at end of file
+    return di
+
+def _read_list(filename=_get_module_path("organization.txt")):
+    res = set()
+    with open(filename, "r") as f:
+        for line in f:
+            res.add(line.strip())
+    return res
\ No newline at end of file
